@@ -16,7 +16,7 @@ sub paste {
     ( $title ? ( title => $title ) : () ),
   });
 
-  unless ($tx->res->is_status_class(200)) {
+  unless ($tx->res->is_success) {
     say $tx->res->message;
     say $tx->res->body;
     exit 1;
